pub enum ConfigWarningKind {
UnusedProvider,
UnusedModel,
UnusedTool,
UnusedAgent,
}Expand description
Categories of configuration warnings.
Variants
UnusedProvider
A provider is defined but not referenced by any model.
UnusedModel
A model is defined but not referenced by any agent.
UnusedTool
A tool is defined but not referenced by any agent.
UnusedAgent
An agent is defined but not referenced by any workflow.