pub struct AresConfigManager { /* private fields */ }Expand description
Thread-safe configuration manager with hot reloading support
Implementations
Sourceimpl AresConfigManager
impl AresConfigManager
Sourcepub fn new<P: AsRef<Path>>(path: P) -> Result<Self, ConfigError>
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, ConfigError>
Create a new configuration manager and load the initial config
Panics
Panics if ares.toml doesn’t exist or is invalid.
Sourcepub fn config(&self) -> Arc<AresConfig> ⓘ
pub fn config(&self) -> Arc<AresConfig> ⓘ
Get the current configuration (lockless read)
Sourcepub fn reload(&self) -> Result<(), ConfigError>
pub fn reload(&self) -> Result<(), ConfigError>
Manually reload the configuration from disk
Sourcepub fn start_watching(&mut self) -> Result<(), ConfigError>
pub fn start_watching(&mut self) -> Result<(), ConfigError>
Start watching for configuration file changes.
Overlay is the only ares.toml program. This forwards to
Self::watch_cordis when a context is already captured and does
not start a second notify watcher stack.
Sourcepub fn stop_watching(&self)
pub fn stop_watching(&self)
Stop watching for configuration changes
Sourceimpl AresConfigManager
impl AresConfigManager
Sourcepub fn from_config(config: AresConfig) -> Self
pub fn from_config(config: AresConfig) -> Self
Create a config manager directly from a config (useful for testing) This won’t have file watching capabilities.
Sourceimpl AresConfigManager
impl AresConfigManager
Sourcepub fn watch_cordis(&self, ctx: &Arc<Context>) -> Result<(), ConfigError>
pub fn watch_cordis(&self, ctx: &Arc<Context>) -> Result<(), ConfigError>
Single Cordis watch for ares.toml plus TOON dirs.
Uses watch_many_with (no second notify stack). ares.toml changes
reload this overlay and notify TypeId::of::<Overlay>(); TOON changes
reload crate::toon_config::DynamicConfigManager and notify Tools
and Execute TypeIds.
Sourcepub fn fill_empty_entry_configs(&self, tree: &mut EntryTree)
pub fn fill_empty_entry_configs(&self, tree: &mut EntryTree)
Fill empty cordis-entry configs from ares.toml sections.
Non-empty loader entry.config values are left unchanged.